@@ -302,7 +302,7 @@ class FrescoApp(object):
 
             found = True
             if self.logger:
-                self.logger.info("gettarget: %s %r => %r", route.method, path,
+                self.logger.info("gettarget: %s %r => %r", request.method, path,
                                  route.original_view)
 
             yield route.view, route, view_args, view_kwargs
