@@ -84,7 +84,7 @@ class XForwarded(object):
         """\
         Call the WSGI app, passing it a modified environ
         """
-        is_ssl = bool(environ.get('HTTP_X_FORWARDED_SSL'))
+        is_ssl = environ.get('HTTP_X_FORWARDED_SSL') == 'on'
 
         if 'HTTP_X_FORWARDED_HOST' in environ:
             host = environ['HTTP_X_FORWARDED_HOST']
