@@ -290,7 +290,10 @@ class Request(object):
             if ':' in host:
                 host, port = host.split(':', 1)
             else:
-                port = self.environ['SERVER_PORT']
+                if scheme == 'https':
+                    port = '443'
+                else:
+                    port = '80'
         except KeyError:
             host = self.environ['SERVER_NAME']
             port = self.environ['SERVER_PORT']
