@@ -26,6 +26,11 @@ class TestRequestProperties(object):
                      HTTP_HOST='localhost:443') as c:
             assert_equal(c.request.url, "https://localhost/")
 
+    def test_url_ignores_server_port_if_host_header_present(self):
+        with context(environ={'wsgi.url_scheme': 'https', 'SERVER_PORT': '81'},
+                     HTTP_HOST='localhost') as c:
+            assert_equal(c.request.url, "https://localhost/")
+
     def test_as_string(self):
         with context('http://example.org/foo?bar=baz') as c:
             assert_equal(str(c.request),
@@ -72,6 +77,7 @@ class TestMakeURL(object):
                          'http://localhost/?a=1;b=2')
 
 
+
 class TestResolveURL(object):
 
     def test_relative_path(self):
@@ -94,6 +100,12 @@ class TestResolveURL(object):
             assert_equal(c.request.resolve_url('/foo', relative='server'),
                          'http://localhost/foo')
 
+    def test_ignores_server_port_if_host_header_present(self):
+        with context(environ={'wsgi.url_scheme': 'https', 'SERVER_PORT': '81'},
+                     HTTP_HOST='localhost') as c:
+            assert_equal(c.request.resolve_url('/foo'),
+                         'https://localhost/foo')
+
 
 class TestCurrentRequest(object):
 
