@@ -1,25 +1,45 @@
 from mock import Mock
 from nose.tools import assert_raises
 from flea import TestAgent
-from fresco import FrescoApp, urlfor, GET, Response
+from fresco import FrescoApp, urlfor, GET, POST, Response
 from fresco.exceptions import BadRequest
 from fresco.routing import resolve_viewspec, Route, \
                            RouteKwarg, CookieArg, FormArg, QueryArg
 from .fixtures import CBV
 
 
+class TestMethodDispatch(object):
+
+    def test_route_is_dispatched_to_correct_method(self):
+
+        getview = Mock(return_value=Response())
+        postview = Mock(return_value=Response())
+        app = FrescoApp()
+        app.route('/', GET, getview)
+        app.route('/', POST, postview)
+
+        TestAgent(app).get('/')
+        assert getview.call_count == 1
+        assert postview.call_count == 0
+
+        TestAgent(app).post('/')
+        assert getview.call_count == 1
+        assert postview.call_count == 1
+
+
 class TestResolveViewSpec(object):
 
     def test_relative_import(self):
-        assert resolve_viewspec('fixtures:CBV', 1) is CBV
+        assert resolve_viewspec('fresco.tests.fixtures:CBV', 1) is CBV
 
     def test_attribute(self):
-        assert resolve_viewspec('fixtures:CBV.index_html', 1) == CBV.index_html
-        assert id(resolve_viewspec('fixtures:CBV.index_html', 1)) == \
-                id(CBV.index_html)
+        assert resolve_viewspec('fresco.tests.fixtures:CBV.index_html', 1) \
+                == CBV.index_html
+        assert id(resolve_viewspec('fresco.tests.fixtures:CBV.index_html', 1))\
+                == id(CBV.index_html)
         # Curiously the object identity test fails. Irritating, but I don't
         # think it matters.
-        #assert resolve_viewspec('fixtures:CBV.index_html', 1) \
+        #assert resolve_viewspec('fresco.tests.fixtures:CBV.index_html', 1) \
         #       is CBV.index_html
 
 
